/********************************************************************************************************
Macro Name:   logLikeRE.sas
Author:       Matthew Psioda
Affiliation:  Department of Biostatistics, University of North Carolina at Chapel Hill
    
**** Program Summary:
      
    Called by %fitRE. This macro sets up the log-likelihood for the MCMC sampler. The macro is  
    not intended to be used in any other context.
      
*********************************************************************************************************/

%macro logLikeRE(px=,scale=1);
    logLikePart1 = 0;
    logLikePart2 = 0;
    logLikePart3 = 0;   
     
    logLikePart1 = nEvent*(
                           %if &frailtyModel = 1 %then %do; &px.logTau + %end; logRate[z+1,x1+1]
                          );
    do k = 1 to &px.K0;
     logLikePart1 = logLikePart1 + nInt[k]*&px.loglambda[k];
    end;  
     
    %if &frailtyModel = 1 %then %do; logLikePart2 = lgamma(&px.tauInv+nEvent) - &px.lgammaTauInv; %end;

    cumHazard = 0;
    do k = 1 to &px.K0;
      if &px.s[k] <= censTime < &px.s[k+1] then do;
        cumHazard = cumHazard + &px.lambda[k]*(censTime-&px.s[k]);
       k = &px.K0 + 1;    
       end;
      else cumHazard = cumHazard + &px.lambda[k]*(&px.s[k+1]-&px.s[k]);
    end;
     
    %if &frailtyModel = 1 %then %do; logLikePart3 = -(&px.tauInv + nEvent)*log(1 + cumHazard*expLogRate[z+1,x1+1] / &px.tauInv); %end; 
    %else %do; logLikePart3 = -cumHazard*expLogRate[z+1,x1+1]; %end;

    logLike =  %if &scale ^=1 %then %do; &scale. * %end;
               (logLikePart1 + logLikePart2 + logLikePart3);   
     
%mend logLikeRE;
