/********************************************************************************************************
Program Name:       example_fitRE.sas
Author:             Matthew Psioda
           
Program Summary:    Example calls to %SimRE and %fitRE macros

*********************************************************************************************************/
%let root    = C:\Users\psioda\Documents\Stat-Projects\Bayesian-recurrent-events-design;
%include "&root./macros/fitRE.sas";
%include "&root./macros/simRE.sas";
%include "&root./macros/blendHC.sas";
%include "&root./macros/logLikeRE.sas";



**********************************************************
********** Case = Non-homogeneous Poisson Process Model w/o Power Prior;
********** Simulation data;

%simRE(
          storeSim      = work.simCase1,     
          studyRepNum   = 5,
          simLoopCount  = 5, /*** Generates 25 total studies in one dataset ***/
          n             = 88,
          lambdaValues  = 0.14|0.31|0.13|0.08, 
          sValues       = 14|21|49,
          tauValue      =  0.000001,
          betaValue     = -1.92,
          gammaValue    = -0.17,
          xDistGen      = rand('bernoulli',0.44),
          zDistGen      = rand('bernoulli',0.50)
       );

%fitRE(
          method             = NORMAL,
          inDS               = work.simCase1,
          mcmcOptions        = ntu=1000 mintune=5 nbi=1000 nmc=50000 nthin=5 propcov=Quanew plots=(none),
          outDS              = work.mcmcResults|work.mcmcRejRates,
          mcmcSeed           = NULL,
          frailtyModel       = 0,
          sValues            = 14|21|49,
          a0                 = NONE,
          phi0List           = 0.95|0.96,
          delta              = 0.975,
          odsOptions         = ods html exclude all;
       );

**********************************************************
********** Case = Gamma Frailty Model w/o Power Prior;
********** Simulation data;
%simRE(
          storeSim     = work.simCase2, 
          n             = 150,
          lambdaValues  = 0.10|0.20,    
          sValues       = 20,
          tauValue      =  1.0,
          betaValue     = -1.50,
          gammaValue    = -0.30,
          xDistGen      = rand('bernoulli',0.44),
          zDistGen      = rand('bernoulli',0.50)
       );

%fitRE(
          method             = NORMAL,
          inDS               = work.simCase2,
          mcmcOptions        = %str(ntu=2000 mintune=10 nbi=1000 nmc=120000 nthin=8 propcov=Quanew plots=(none)),
          outDS              = work.mcmcResults|work.mcmcRejRates,
          mcmcSeed           = NULL,
          frailtyModel       = 1,
          sValues            = 20,
          a0                 = NONE,
          phi0List           = 0.95|0.96,
          delta              = 0.975,
          odsOptions         = ods html select PostSummaries;
       );


**********************************************************
********** Case = Non-homogeneous Poisson Process Model with Power Prior;

%simRE(
          storeSim     = work.simCase3, 
          n             = 200,
          lambdaValues  = 0.10|0.20,    
          sValues       = 20,
          tauValue      =  0.000001,
          betaValue     = -1.80,
          gammaValue    = -0.30,
          xDistGen      = rand('bernoulli',0.44),
          zDistGen      = rand('bernoulli',0.50)
       );

%simRE(
          storeSim     = work.hc_simCase3,   
          n             = 100,
          lambdaValues  = 0.20|0.10|0.07,    
          sValues       = 20|40,
          tauValue      =  0.000001,
          betaValue     = -1.80,
          gammaValue    = -0.30,
          xDistGen      = rand('bernoulli',0.44),
          zDistGen      = rand('bernoulli',0.50)
       );

%fitRE(
          method             = NORMAL,
          inDS               = work.simCase3,
          mcmcOptions        = ntu=2000 mintune=10 nbi=1000 nmc=120000 nthin=8 propcov=Quanew plots=(none),
          outDS              = work.mcmcResults|work.mcmcRejRates,
          mcmcSeed           = NULL,
          frailtyModel       = 0,
          sValues            = 20,
          a0                 = 0.25,
           hc_sValues         = 20|40,
           hc_loglambda_start = %sysfunc(log(0.20))|%sysfunc(log(0.10))|%sysfunc(log(0.07)),
           hcDataset          = hc_simCase3,
          phi0List           = 0.95|0.96,
          delta              = 0.975,
          odsOptions         = ods html select PostSummaries;
       );


**********************************************************
********** Case = Gamma Frailty Model with Power Prior;

%simRE(
          storeSim     = work.simCase4, 
          n             = 200,
          lambdaValues  = 0.10|0.20,    
          sValues       = 20,
          tauValue      =  1.0,
          betaValue     = -1.80,
          gammaValue    = -0.30,
          xDistGen      = rand('bernoulli',0.44),
          zDistGen      = rand('bernoulli',0.50)
       );

%simRE(
          storeSim     = work.hc_simCase4,   
          n             = 100,
          lambdaValues  = 0.20|0.10|0.07,    
          sValues       = 20|40,
          tauValue      =  1.25,
          betaValue     = -1.80,
          gammaValue    = -0.30,
          xDistGen      = rand('bernoulli',0.44),
          zDistGen      = rand('bernoulli',0.50)
       );

%fitRE(
          method             = NORMAL,
          inDS               = work.simCase4,
          mcmcOptions        = ntu=2000 mintune=10 nbi=1000 nmc=120000 nthin=8 propcov=Quanew plots=(none),
          outDS              = work.mcmcResults|work.mcmcRejRates,
          mcmcSeed           = NULL,
          frailtyModel       = 1,
          sValues            = 20,
          a0                 = 0.25,
           hc_sValues         = 20|40,
           hc_loglambda_start = %sysfunc(log(0.20))|%sysfunc(log(0.10))|%sysfunc(log(0.07)),
           hc_logTauInv_start = %sysfunc(log(1/1.25)),
           hcDataset          = hc_simCase4,
          phi0List           = 0.95|0.96,
          delta              = 0.975,
          odsOptions         = ods html select PostSummaries;
       );
